From aae78162d2e42e6f27a270c00f8b83f948c18c75 Mon Sep 17 00:00:00 2001
From: Ian Darwin <ian@darwinsys.com>
Date: Fri, 11 Sep 1992 12:07:27 +0000
Subject: [PATCH] Use ckfprintf to say "broken symlink...".

---
 src/fsmagic.c | 7 ++++---
 1 file changed, 4 insertions(+), 3 deletions(-)

diff --git a/src/fsmagic.c b/src/fsmagic.c
index 514a3819..5bf050de 100644
--- a/src/fsmagic.c
+++ b/src/fsmagic.c
@@ -46,7 +46,7 @@
 
 #ifndef	lint
 static char *moduleid = 
-	"@(#)$Id: fsmagic.c,v 1.17 1992/09/11 11:33:41 ian Exp $";
+	"@(#)$Id: fsmagic.c,v 1.18 1992/09/11 12:07:27 ian Exp $";
 #endif	/* lint */
 
 int
@@ -108,9 +108,10 @@ struct stat *sb;
 			}
 			buf[nch] = '\0';	/* readlink(2) forgets this */
 
 			/* If dangling symlink, say so and quit early. */
 			if (stat(buf, &tstatbuf) < 0) {
-				printf("dangling symbolic link to %s", fn);
+				ckfprintf(stdout,
+					"broken symbolic link to %s\n", buf);
 				return 1;
 			}
 
@@ -108,9 +108,10 @@ struct stat *sb;
 			buf[nch] = '\0';	/* readlink(2) forgets this */
 
-			/* If dangling symlink, say so and quit early. */
+			/* If broken symlink, say so and quit early. */
 			if (stat(buf, &tstatbuf) < 0) {
-- 
2.40.0